function etaR = computeEtaR_pict(pict,elements,coordinates)
  etaR= zeros(1,size(elements,1));    

  for i=1:size(elements,1)
    %*** define grid around i-th triangle
    sxmin = floor(min(coordinates(elements(i,:),1)));
    sxmax = ceil(max(coordinates(elements(i,:),1)));
    symin = floor(min(coordinates(elements(i,:),2)));
    symax = ceil(max(coordinates(elements(i,:),2)));
    %*** compute inner points
    [~,~,M] = chkinout(sxmin:sxmax,symin:symax,coordinates(elements(i,:),:),[1,2;2,3;3,1]);
    idx = find(M);
    %*** compute local matrix of picture
    pictLoc = pict(symin:symax,sxmin:sxmax);
    %*** compute refinement indicator
    if ~isempty(idx)
      etaR(i) = max(max(pictLoc(idx)))-min(min(pictLoc(idx)));
    else
      etaR(i)=0;
    end
  end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% @function   chkinout.m verifies, if points are contained in a polygon 
% @param:     xx          -   vector of points for x axis
%             yy          -   vector of points for y axis
%             coordinates -   vector of vertices
%             edges       -   edges are NOT ordered
% @return:    X           -   see meshgrid
%             Y           -   see meshgrid
%             Z           -   logical matrix, 1 -> point is in set
%                                             0 -> point is NOT in set
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [ X , Y , Z ] = chkinout( xx , yy , coordinates , edges )

c = find_comp(edges);
coordinates_sorted0=[0,0];
coordinates_sorted1=[3,5];
for i=1:length(c)
  coordinates_sorted0 = [coordinates_sorted0; coordinates(c{i},:);0,0];
  coordinates_sorted1 = [coordinates_sorted1; coordinates(c{i},:);3,5];
end

%calculate bounding box, Z(i,j) = 1 if in boundig box, else Z(i,j) = 0
xymin = min(coordinates,[],1);
xymax = max(coordinates,[],1);

zx = find( ( xx(:) >= xymin(1) ) & ( xx(:) <= xymax(1) ) );
zy = find( ( yy(:) >= xymin(2) ) & ( yy(:) <= xymax(2) ) );
[ X , Y ] = meshgrid( xx(zx) , yy(zy) );

warning off
pin0=inpoly(coordinates_sorted0(:,1),coordinates_sorted0(:,2),X(:),Y(:));
pin1=inpoly(coordinates_sorted1(:,1),coordinates_sorted1(:,2),X(:),Y(:));
warning on
pin = pin0|pin1;

Z = zeros(length(yy),length(xx));
Z(zy,zx) = reshape(pin,length(zy),length(zx));
if nargout == 3
  [X,Y] = meshgrid( xx(:) , yy(:) );
end

function c = find_comp(elements)
used = ones(size(elements,1),1);
map(elements(:,1))=1:size(elements,1);
anz_comp = 0;
while any(used)
  i = find(used);
  i = i(1);
  comp = elements(i,:);
  a = comp(1);
  next = comp(2);
  used(i) = 0;
  while a~=next
    i = map(next);
    comp = [comp;elements(i,:)];
    next = comp(end,2);
    used(i) = 0;
  end
  anz_comp = anz_comp + 1;
  c{anz_comp} = [comp(:,1);comp(1,1)];
end
